@@ -5,13 +5,16 @@
 #' @param label String. The checkbox label.
 #' @param initial_value Boolean. Is the checkbox initially checked?
 #' @param color String. The color of the check. Leave empty for the default color. Visit \url{http://materializecss.com/color.html} for a list of available colors. \emph{This input requires using color hex codes, rather than the word form. E.g., "#ef5350", rather than "red lighten-1".}
+#' @seealso \code{\link{update_material_checkbox}}
 #' @examples
+#' \dontrun{
 #' material_checkbox(
 #'   input_id = "example_checkbox",
 #'   label = "Checkbox",
 #'   initial_value = TRUE,
 #'   color = "#ef5350"
 #' )
+#' }
 material_checkbox <- function(input_id, label, initial_value = FALSE, color = NULL) {
   
   if(!is.null(color)){
@@ -21,28 +24,23 @@ material_checkbox <- function(input_id, label, initial_value = FALSE, color = NU
         shiny::tags$head(
           shiny::tags$style(
             paste0(
-              '
-              .shinymaterial-checkbox-', input_id,':checked + label:before {
+              "
+              #", input_id, "[type='checkbox']:checked+span:not(.lever):before {
               top: -4px;
-              left: -3px;
+              left: -5px;
               width: 12px;
               height: 22px;
               border-top: 2px solid transparent;
               border-left: 2px solid transparent;
-              border-right: 2px solid ', color, ';
-              border-bottom: 2px solid ', color, ';
+              border-right: 2px solid ", color, ";
+              border-bottom: 2px solid ", color, ";
               -webkit-transform: rotate(40deg);
-              -moz-transform: rotate(40deg);
-              -ms-transform: rotate(40deg);
-              -o-transform: rotate(40deg);
               transform: rotate(40deg);
               -webkit-backface-visibility: hidden;
+              backface-visibility: hidden;
               -webkit-transform-origin: 100% 100%;
-              -moz-transform-origin: 100% 100%;
-              -ms-transform-origin: 100% 100%;
-              -o-transform-origin: 100% 100%;
               transform-origin: 100% 100%; }
-              '
+              "
             )
           )
         )
@@ -61,26 +59,25 @@ material_checkbox <- function(input_id, label, initial_value = FALSE, color = NU
           action = "#",
           class = "shiny-material-checkbox",
           shiny::tags$p(
-            shiny::HTML(
-              paste0(
-                '<input type="checkbox" id="',
-                input_id,
-                '"',
-                ifelse(
-                  is.null(color),
-                  "",
-                  paste0(' class="shinymaterial-checkbox-', input_id, '"')
-                ),
-                ifelse(
-                  initial_value,
-                  ' checked="checked"/>',
-                  '/>'
-                )
-              )
-            ),
             shiny::tags$label(
-              `for` = input_id,
-              label
+              shiny::HTML(
+                paste0(
+                  '<input type="checkbox" id="',
+                  input_id,
+                  '"',
+                  ifelse(
+                    is.null(color),
+                    "",
+                    paste0(' class="shinymaterial-checkbox-', input_id, '"')
+                  ),
+                  ifelse(
+                    initial_value,
+                    ' checked="checked"/>',
+                    '/>'
+                  )
+                )
+              ),
+              shiny::tags$span(id = paste0(input_id, "-span"), label)
             )
           )
         ),
