@@ -3,6 +3,7 @@
 #' Build a shinymaterial floating button. The initial value is zero, and increases by one on each press.
 #' @param input_id String. The input identifier used to access the value.
 #' @param icon String. The name of the icon. Leave empty for no icon. Visit \url{http://materializecss.com/icons.html} for a list of available icons.
+#' @param pulse Boolean. Include pulse effect.
 #' @param depth Integer. The amount of depth of the floating button. The value should be between 0 and 5. Leave empty for the default depth.
 #' @param color String. The color of the floating button. Leave empty for the default color. Visit \url{http://materializecss.com/color.html} for a list of available colors.
 #' @examples
@@ -12,7 +13,7 @@
 #'   depth = 5,
 #'   color = "red lighten-3"
 #' )
-material_floating_button <- function(input_id, icon = NULL, depth = NULL, color = NULL) {
+material_floating_button <- function(input_id, icon = NULL, pulse = FALSE, depth = NULL, color = NULL) {
   
   create_material_object(
     js_file =
@@ -30,6 +31,11 @@ material_floating_button <- function(input_id, icon = NULL, depth = NULL, color
                   "",
                   paste0(" z-depth-", depth)
                 ),
+                ifelse(
+                  pulse,
+                  " pulse",
+                  ""
+                ),
                 ifelse(
                   is.null(color),
                   "",
@@ -38,9 +44,9 @@ material_floating_button <- function(input_id, icon = NULL, depth = NULL, color
               ),
             style =
               ifelse(
-                !is.null(color),
+                is.null(color),
                 "",
-                "background-color:#F06C71"
+                paste0("background-color:", color)
               ),
             id = input_id,
             value = 0,
