@@ -4,6 +4,7 @@
 #' @param session The session object passed to function given to shinyServer.
 #' @param input_id The input_id of the material_text_box.
 #' @param value The value to set for the material_text_box.
+#' @seealso \code{\link{material_text_box}}
 #' @examples
 #' \dontrun{
 #' update_material_text_box(
@@ -19,7 +20,7 @@ update_material_text_box <- function(session, input_id, value = NULL){
   session$sendCustomMessage(
     type = "shinymaterialJS",
     paste0(
-        "$('#", input_id, "').val('", value, "');Shiny.onInputChange('", input_id, "', '", value, "');Materialize.updateTextFields()"
+        "$('#", input_id, "').val('", value, "');Shiny.onInputChange('", input_id, "', '", value, "');M.updateTextFields()"
     )
   )
 }
